@@ -17,12 +17,12 @@
 //!
 //! For a 3d game:
 //! ```toml
-//! heron = { version = "0.13.0", features = ["3d"] }
+//! heron = { version = "1.0.1", features = ["3d"] }
 //! ```
 //!
 //! For as 2d game:
 //! ```toml
-//! heron = { version = "0.13.0", features = ["2d"] }
+//! heron = { version = "1.0.1", features = ["2d"] }
 //! ```
 //!
 //! ### Feature flags
@@ -42,7 +42,7 @@
 //! use heron::prelude::*;
 //!
 //! fn main() {
-//!   App::build()
+//!   App::new()
 //!     .add_plugins(DefaultPlugins)
 //!     .add_plugin(PhysicsPlugin::default())
 //!     // ... Add your resources and systems
@@ -120,7 +120,7 @@
 //! * How to define [`RotationConstraints`]
 //! * How to define [`CustomCollisionShape`] for [`heron_rapier`]
 
-use bevy::app::{AppBuilder, Plugin};
+use bevy::app::{App, Plugin};
 
 pub use heron_core::*;
 pub use heron_macros::*;
@@ -154,7 +154,7 @@ pub struct PhysicsPlugin {
 }
 
 impl Plugin for PhysicsPlugin {
-    fn build(&self, app: &mut AppBuilder) {
+    fn build(&self, app: &mut App) {
         app.add_plugin(RapierPlugin);
 
         #[cfg(debug)]
